==> pointsto-23.1.3.jar: module-info.java <==
module org.graalvm.nativeimage.pointsto {
    requires java.management;
    requires jdk.internal.vm.ci;
    /* transitive */ requires jdk.internal.vm.compiler;
    requires jdk.management;
    /* transitive */ requires org.graalvm.collections;
    /* transitive */ requires org.graalvm.nativeimage;
    /* transitive */ requires org.graalvm.nativeimage.base;
    /* transitive */ requires org.graalvm.truffle.compiler;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.graal.pointsto;
    exports com.oracle.graal.pointsto.api;
    exports com.oracle.graal.pointsto.constraints;
    exports com.oracle.graal.pointsto.flow;
    exports com.oracle.graal.pointsto.flow.builder;
    exports com.oracle.graal.pointsto.flow.context.bytecode;
    exports com.oracle.graal.pointsto.flow.context.object;
    exports com.oracle.graal.pointsto.heap;
    exports com.oracle.graal.pointsto.heap.value;
    exports com.oracle.graal.pointsto.infrastructure;
    exports com.oracle.graal.pointsto.meta;
    exports com.oracle.graal.pointsto.nodes;
    exports com.oracle.graal.pointsto.phases;
    exports com.oracle.graal.pointsto.reports;
    exports com.oracle.graal.pointsto.results;
    exports com.oracle.graal.pointsto.typestate;
    exports com.oracle.graal.pointsto.util;

    provides OptionDescriptors with HeapSnapshotVerifier_OptionDescriptors, StrengthenGraphs_OptionDescriptors, InlineBeforeAnalysis_OptionDescriptors, AnalysisReportsOptions_OptionDescriptors, PointstoOptions_OptionDescriptors;

}

==> pointsto-23.1.5.jar: module-info.java <==
module org.graalvm.nativeimage.pointsto {
    requires java.management;
    requires jdk.internal.vm.ci;
    /* transitive */ requires jdk.internal.vm.compiler;
    requires jdk.management;
    /* transitive */ requires org.graalvm.collections;
    /* transitive */ requires org.graalvm.nativeimage;
    /* transitive */ requires org.graalvm.nativeimage.base;
    /* transitive */ requires org.graalvm.truffle.compiler;
    /* transitive */ requires org.graalvm.word;

    exports com.oracle.graal.pointsto;
    exports com.oracle.graal.pointsto.api;
    exports com.oracle.graal.pointsto.constraints;
    exports com.oracle.graal.pointsto.flow;
    exports com.oracle.graal.pointsto.flow.builder;
    exports com.oracle.graal.pointsto.flow.context.bytecode;
    exports com.oracle.graal.pointsto.flow.context.object;
    exports com.oracle.graal.pointsto.heap;
    exports com.oracle.graal.pointsto.heap.value;
    exports com.oracle.graal.pointsto.infrastructure;
    exports com.oracle.graal.pointsto.meta;
    exports com.oracle.graal.pointsto.nodes;
    exports com.oracle.graal.pointsto.phases;
    exports com.oracle.graal.pointsto.reports;
    exports com.oracle.graal.pointsto.results;
    exports com.oracle.graal.pointsto.typestate;
    exports com.oracle.graal.pointsto.util;

    provides OptionDescriptors with InlineBeforeAnalysis_OptionDescriptors, HeapSnapshotVerifier_OptionDescriptors, StrengthenGraphs_OptionDescriptors, AnalysisReportsOptions_OptionDescriptors, PointstoOptions_OptionDescriptors;

}
